Learn R Programming

DPTM (version 1.6.0)

DPML: The dynamic panel linear model with fixed effects

Description

The dynamic panel linear model with fixed effects

Usage

DPML(
  y,
  y1 = NULL,
  x = NULL,
  w = NULL,
  var_u = NULL,
  tt,
  nn,
  time_trend = FALSE,
  time_fix_effects = FALSE,
  restart = FALSE,
  x1 = NULL,
  delty0 = NULL,
  Only_b = FALSE,
  display = TRUE
)

Value

A list containing the following components:

ssemin

the negaive log-likelihood function value

Coefs

parameter estimates containing Z-values

pars

iterated results for all parameters

duit

the first-difference form of residuals

dy0

the first-difference form of dependent variable

xx

the independent variables and their initial values

covariance_matrix

the covariance matrix

Ses

the standard errors of coefs

Zvalues

the values of the statistic

ccd

the number of independent variables

coefs

parameter estimates containing their initial valuess

Arguments

y

the dependent variable; vector type input.

y1

the lag dependent variable; vector type input; By default, y1 is NULL, and then y1 will be computed by y automatically.

x

the independent variable; matrix type input.

w

the variance ratio; By default, is NULL; It must be greater than 1.

var_u

the option of variance of error term; By default, is NULL; It must be greater than 0; When meet relevant ERROR, please change the var_u.

tt

the length of time period.

nn

the number of individuals.

time_trend

the time trend; By default, it is FALSE.

time_fix_effects

the time fixed effects; By default, it is FALSE.

restart

the option of iterations; By default, restart is FALSE, if encounters iteration failure, please set restart as TRUE.

x1

the initial values of independent variable; matrix type input. By default, x1 is NULL, and thus x1 will be computed by x automatically.

delty0

the option of delta_y; By default, delty0 is NULL; Please do not change delty0.

Only_b

the option of initial equation;By default, Only_b is FALSE, and if Only_b is TRUE, initial delta y will be a constant C. Please see Hsiao (2002) and Ramírez-Rondán (2020) for more details.

display

the option of whether to print the messages of estimated results; By default, the display is TRUE.

Functions

  • DPML(): This is an dynamic panel linear model with fixed effects, which allows time trend term or time fixed effects.

Author

Hujie Bai

References

Ramírez-Rondán, N. R. (2020). Maximum likelihood estimation of dynamic panel threshold models. Econometric Reviews, 39(3), 260-276.

Hsiao, C., Pesaran, M. H., & Tahmiscioglu, A. K. (2002). Maximum likelihood estimation of fixed effects dynamic panel data models covering short time periods. Journal of econometrics, 109(1), 107-150.

Examples

Run this code
data("data", package = "DPTM")
y <- data$data_test_linear$y
q <- data$data_test_linear$q
x <- as.matrix(data$data_test_linear$x)
z <- as.matrix(data$data_test_linear$z)
tt <- data$data_test_linear$tt
nn <- data$data_test_linear$nn
xx <- cbind(x,z)
m1 <- DPML(y=y,x=xx,tt=tt,nn=nn)
m1$Coefs

Run the code above in your browser using DataLab