Use a MCMC-MLE based on two-step procedure to estimate the dynamic panel multiple threshold model with fixed effects.
[R6::R6Class] object.
coefficientsa named vector of coefficients
NNLLthe negative log-likelihood function value
Zvaluesa vector of t statistics
Sesa vector of standard errors
covariance_matrixa covariance matrix
duita vector of residuals after difference
dy0a vector of dependent variable after difference
Ththe number of thresholds
thresholdsa named vector of thresholds
new()initialize Initializing method
DPTM$new(
data,
index = NULL,
Th = NULL,
iterations = NULL,
sro = NULL,
w = NULL,
var_u = NULL,
iterlim = NULL,
restart = FALSE,
delty0 = NULL
)datadata.frame used
indexvariable names of individuals and period; If a setting is not provided, defaults (the first variables in data will be as "id", while the second will be "year") will be used
Thnumber of thresholds; If a setting is not provided, defaults (Th = 0) will be used
iterationsMCMC iterations (50% used for burnining)
sroregime (subsample) proportion; If a setting is not provided, defaults (10%) will be used
wvariances ratio initial value; If a setting is not provided, defaults (automatic calculation) will be used
var_uvariances (T>=2) initial value; If a setting is not provided, defaults (automatic calculation) will be used
iterlimthe maximum number of iterations; If a setting is not provided, defaults (iterlim = 500) will be used
restartlogicals. If MLE fails, set it as TRUE
delty0a vector of dependent variable after difference
capture_input()Identify and capturing inputs
DPTM$capture_input(
formula = NULL,
formula_cv = NULL,
timeFE,
y1 = NULL,
q = NULL,
r0x = NULL,
r1x = NULL,
NoY = FALSE
)formulaformula of the covariates with threshold effects;If a setting is not provided, defaults (no covariates with threshold effects) will be used
formula_cvformula of the covariates without threshold effects;If a setting is not provided, defaults (no covariates without threshold effects) will be used
timeFElogicals. If TRUE the time fixed effects will be allowed
y1lags of dependent variables; If a setting is not provided, defaults (the first-order lag) will be used
qthreshold variable
r0xlower bound of threshold parameter space; If a setting is not provided, defaults (15% quantile of threshold variable) will be used
r1xupper bound of threshold parameter space; If a setting is not provided, defaults (85% quantile of threshold variable) will be used
NoYlogicals. If TRUE the lags of dependent variables will be without threshold effects
MLE()Maximum likelihood estimation method
DPTM$MLE(ny = 1)nythe number of regimes
TModel_fit()Compute coefficients given thresholds
DPTM$TModel_fit(ga)gathresholds
MCMC_process()Use MCMC to compute thresholds
DPTM$MCMC_process(
proportion = 0.5,
types = "DREAMzs",
ADs = FALSE,
nCR = 3,
...
)proportionthe proportion of burning in the whole iterations
typesthe type of MCMC, see BayesianTools::runMCMC
ADsthe parameter of MCMC, see BayesianTools::runMCMC
nCRthe parameter of MCMC, see BayesianTools::runMCMC
...the settings of MCMC, see BayesianTools::applySettingsDefault
...DPTM object
clone()The objects of this class are cloneable with this method.
DPTM$clone(deep = FALSE)deepWhether to make a deep clone.