- y
the dependent variable; vector type input.
- y1
the lag dependent variable; vector type input; By default, y1 is NULL,
and then y1 will be computed by y automatically.
- x
the independent variable; matrix type input.
- w
the variance ratio; By default, is NULL; It must be greater than 1.
- var_u
the option of variance of error term; By default, is NULL; It must be
greater than 0; When meet relevant ERROR, please change the var_u.
- tt
the length of time period.
- nn
the number of individuals.
- time_trend
the time trend; By default, it is FALSE.
- time_fix_effects
the time fixed effects; By default, it is FALSE.
- restart
the option of iterations; By default, restart is FALSE,
if encounters iteration failure, please set restart as TRUE.
- x1
the initial values of independent variable; matrix type input.
By default, x1 is NULL, and thus x1 will be computed by x automatically.
- delty0
the option of delta_y; By default, delty0 is NULL; Please do not change delty0.
- Only_b
the option of initial equation;By default, Only_b is FALSE, and if Only_b is TRUE, initial delta y will be a constant C.
Please see Hsiao (2002) and Ramírez-Rondán (2020) for more details.
- display
the option of whether to print the messages of estimated results; By default, the display is TRUE.